==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/eu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zehaztutako eragilea baliogabea da",
    "The given regular expression is invalid" : "Zehaztutako adierazpen erregularra baliogabea da",
    "The given file size is invalid" : "Zehaztutako fitxategi tamaina baliogabea da",
    "The given tag id is invalid" : "Zehaztutako etiketa baliogabea da",
    "The given IP range is invalid" : "Zehaztutako IP barrutia baliogabea da",
    "The given IP range is not valid for IPv4" : "Zehaztutako IP barrutia baliogabea da IPv4-rentzat",
    "The given IP range is not valid for IPv6" : "Zehaztutako IP barrutia baliogabea da IPv6-rentzat",
    "The given time span is invalid" : "Zehaztutako denbora tartea baliogabea da",
    "The given start time is invalid" : "Zehaztutako hasiera ordua baliogabea da",
    "The given end time is invalid" : "Zehaztutako amaiera ordua baliogabea da",
    "The given group does not exist" : "Ez dago zehaztutako talde hori",
    "File" : "Fitxategia",
    "File created" : "Fitxategia sortuta",
    "File updated" : "Fitxategia eguneratuta",
    "File renamed" : "Fitxategia izenez aldatuta",
    "File deleted" : "Fitxategia ezabatuta",
    "File accessed" : "Fitxategia atzituta",
    "File copied" : "Fitxategia kopiatuta",
    "Tag assigned" : "Etiketa esleituta",
    "Someone" : "Norbait",
    "%s created %s" : "%s(e)k %s sortu du",
    "%s modified %s" : "%s(e)k %s aldatu du",
    "%s deleted %s" : "%s(e)k %s ezabatu du",
    "%s accessed %s" : "%s(e)k %s atzitu du",
    "%s renamed %s" : "%s(e)k %s izenez aldatu du",
    "%s copied %s" : "%s(e)k %s kopiatu du",
    "%s assigned %s to %s" : "%s(e)k %s esleitu dio %s(e)ri",
    "Operation #%s does not exist" : "Ez dago #%s eragiketarik",
    "Entity %s does not exist" : "Ez dago %s entitaterik",
    "Entity %s is invalid" : "%s entitatea baliogabea da",
    "No events are chosen." : "Ez da gertaerarik aukeratu.",
    "Entity %s has no event %s" : "%s entitateak ez du %s gertaerarik",
    "Operation %s does not exist" : "Ez dago %s eragiketarik",
    "Operation %s is invalid" : "%seragiketa baliogabea da",
    "Select a filter" : "Hautatu iragazki bat",
    "Select a file type" : "Hautatu fitxategi mota bat",
    "e.g. httpd/unix-directory" : "adib. httpd/unix-direktorioa",
    "Images" : "Irudiak",
    "PDF documents" : "PDF dokumentuak",
    "Select a tag" : "Hautatu etiketa bat",
    "No results" : "Emaitzarik ez",
    "%s (invisible)" : "%s (ikusezina)",
    "%s (restricted)" : "%s (mugatua)",
    "Please enter a valid time span" : "Sartu baliozko denbora tarte bat",
    "Others" : "Besteak",
    "Android client" : "Android bezeroa",
    "iOS client" : "iOS bezeroa",
    "Desktop client" : "Mahaigaineko bezeroa",
    "When" : "Noiz",
    "and" : "eta",
    "Cancel" : "Utzi",
    "Delete" : "Ezabatu",
    "Active" : "Aktiboa",
    "Save" : "Gorde",
    "Show less" : "Erakutsi gutxiago",
    "Show more" : "Erakutsi gehiago",
    "File name" : "Fitxategi-izena",
    "is" : "da",
    "is not" : "ez da",
    "matches" : "bat dator",
    "does not match" : "ez dator bat",
    "less" : "gutxiago",
    "less or equals" : "gutxiago edo berdin",
    "greater or equals" : "gehiago",
    "greater" : "gehiago edo berdin",
    "Add rule" : "Gehitu araua",
    "Saving…" : "Gordetzen…",
    "Group list is empty" : "Talde zerrenda hutsik dago",
    "Saved" : "Gordeta",
    "Example: {placeholder}" : "Adibidea: {placeholder}",
    "Select tag…" : "Hautatu etiketa…",
    "Start" : "Hasiera",
    "End" : "Amaiera",
    "Sync clients" : "Sinkronizatu bezeroak",
    "Open documentation" : "Ireki dokumentazioa",
    "Loading…" : "Kargatzen…",
    "Tag management" : "Etiketen kudeaketa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/eu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zehaztutako eragilea baliogabea da",
    "The given regular expression is invalid" : "Zehaztutako adierazpen erregularra baliogabea da",
    "The given file size is invalid" : "Zehaztutako fitxategi tamaina baliogabea da",
    "The given tag id is invalid" : "Zehaztutako etiketa baliogabea da",
    "The given IP range is invalid" : "Zehaztutako IP barrutia baliogabea da",
    "The given IP range is not valid for IPv4" : "Zehaztutako IP barrutia baliogabea da IPv4-rentzat",
    "The given IP range is not valid for IPv6" : "Zehaztutako IP barrutia baliogabea da IPv6-rentzat",
    "The given time span is invalid" : "Zehaztutako denbora tartea baliogabea da",
    "The given start time is invalid" : "Zehaztutako hasiera ordua baliogabea da",
    "The given end time is invalid" : "Zehaztutako amaiera ordua baliogabea da",
    "The given group does not exist" : "Ez dago zehaztutako talde hori",
    "File" : "Fitxategia",
    "File created" : "Fitxategia sortuta",
    "File updated" : "Fitxategia eguneratuta",
    "File renamed" : "Fitxategia izenez aldatuta",
    "File deleted" : "Fitxategia ezabatuta",
    "File accessed" : "Fitxategia atzituta",
    "File copied" : "Fitxategia kopiatuta",
    "Tag assigned" : "Etiketa esleituta",
    "Someone" : "Norbait",
    "%s created %s" : "%s(e)k %s sortu du",
    "%s modified %s" : "%s(e)k %s aldatu du",
    "%s deleted %s" : "%s(e)k %s ezabatu du",
    "%s accessed %s" : "%s(e)k %s atzitu du",
    "%s renamed %s" : "%s(e)k %s izenez aldatu du",
    "%s copied %s" : "%s(e)k %s kopiatu du",
    "%s assigned %s to %s" : "%s(e)k %s esleitu dio %s(e)ri",
    "Operation #%s does not exist" : "Ez dago #%s eragiketarik",
    "Entity %s does not exist" : "Ez dago %s entitaterik",
    "Entity %s is invalid" : "%s entitatea baliogabea da",
    "No events are chosen." : "Ez da gertaerarik aukeratu.",
    "Entity %s has no event %s" : "%s entitateak ez du %s gertaerarik",
    "Operation %s does not exist" : "Ez dago %s eragiketarik",
    "Operation %s is invalid" : "%seragiketa baliogabea da",
    "Flow" : "Fluxua",
    "Select a filter" : "Hautatu iragazki bat",
    "Select a file type" : "Hautatu fitxategi mota bat",
    "e.g. httpd/unix-directory" : "adib. httpd/unix-direktorioa",
    "Images" : "Irudiak",
    "PDF documents" : "PDF dokumentuak",
    "Select a tag" : "Hautatu etiketa bat",
    "No results" : "Emaitzarik ez",
    "%s (invisible)" : "%s (ikusezina)",
    "%s (restricted)" : "%s (mugatua)",
    "Please enter a valid time span" : "Sartu baliozko denbora tarte bat",
    "Others" : "Besteak",
    "Android client" : "Android bezeroa",
    "iOS client" : "iOS bezeroa",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook gehigarriak",
    "When" : "Noiz",
    "and" : "eta",
    "Cancel" : "Utzi",
    "Delete" : "Ezabatu",
    "Active" : "Aktiboa",
    "Save" : "Gorde",
    "Show less" : "Erakutsi gutxiago",
    "Show more" : "Erakutsi gehiago",
    "matches" : "bat dator",
    "does not match" : "ez dator bat",
    "is" : "da",
    "is not" : "ez da",
    "File name" : "Fitxategi-izena",
    "less" : "gutxiago",
    "less or equals" : "gutxiago edo berdin",
    "greater or equals" : "gehiago",
    "greater" : "gehiago edo berdin",
    "File system tag" : "Fitxategi sistemako etiketa",
    "Add rule" : "Gehitu araua",
    "Reset" : "Berrezarri",
    "Saving…" : "Gordetzen…",
    "Group list is empty" : "Talde zerrenda hutsik dago",
    "Unable to retrieve the group list" : "Ezin izan da talde zerrenda eskuratu",
    "Saved" : "Gordeta",
    "Example: {placeholder}" : "Adibidea: {placeholder}",
    "Select tag…" : "Hautatu etiketa…",
    "Start" : "Hasiera",
    "End" : "Amaiera",
    "Sync clients" : "Sinkronizatu bezeroak",
    "Open documentation" : "Ireki dokumentazioa",
    "Loading…" : "Kargatzen…",
    "Tag management" : "Etiketen kudeaketa"
},
"nplurals=2; plural=(n != 1);");
